@@ -24,8 +24,27 @@ QUOTE_FOLDER = Path(__file__).parent
 QUOTE_FILE_NAME = "qts.txt"
 QUOTE_FILE = QUOTE_FOLDER / QUOTE_FILE_NAME
 
-TIMER_WORK = (20 * 60, 20 * 60, 40 * 60, 50 * 60)
-TIMER_BREAK = (20 * 60, 10 * 60, 20 * 60, 10 * 60)
+TIMER_WORK_MINS =  (20 , 20 , 40 , 50)
+TIMER_BREAK_MINS = (20 , 10 , 20 , 10)
+
+TIMER_WORK = (
+	TIMER_WORK_MINS[0] * 60, 
+	TIMER_WORK_MINS[1] * 60, 
+	TIMER_WORK_MINS[2] * 60, 
+	TIMER_WORK_MINS[3] * 60)
+
+TIMER_BREAK = (
+	TIMER_BREAK_MINS[0] * 60, 
+	TIMER_BREAK_MINS[1] * 60, 
+	TIMER_BREAK_MINS[2] * 60, 
+	TIMER_BREAK_MINS[3] * 60)
+
+SOUNDS_MUTED = False # This is for only growth and start_timer, alarm stays
+TIMER_START_SOUND = str(RES_FOLDER / "timerstart.wav")
+ALARM_SOUND = str(RES_FOLDER / "alarm.wav")
+GROWTH_SOUND = str(RES_FOLDER/ "growth.waw")
+
+effect_volume = 100 # How loud sound effects are, not including ambience and music.
 
 __all__ = ["run_app"]
 
@@ -49,6 +68,19 @@ def get_user_config_directory():
         return xdg_config_home
     return os.path.join(os.path.expanduser("~"), ".config")
 
+def play_sound(sound):
+
+    if SOUNDS_MUTED and sound != ALARM_SOUND:
+        return
+
+    media = vlc.MediaPlayer(sound)
+    media.audio_set_volume(effect_volume)
+    media.play()
+
+def toggle_sounds():
+    global SOUNDS_MUTED
+    SOUNDS_MUTED = not SOUNDS_MUTED
+
 def isinternet():
     try:
         urllib.request.urlopen("https://youtube.com", timeout = 10) #Python 3.x
@@ -114,6 +146,9 @@ def printart(
 
 
 def key_events(stdscr, tree1, maxx):
+
+    global effect_volume # Used for setting the sound effect volume with '{' and '}'
+
     key = stdscr.getch()
 
     if key in (curses.KEY_UP, ord("k")):
@@ -132,15 +167,13 @@ def key_events(stdscr, tree1, maxx):
                 tree1.starttimer(tree1.selectedtimer, stdscr, maxx)
             else:
                 tree1.featureselect(tree1.selectedtimer, maxx, stdscr)
-            timerstart = vlc.MediaPlayer(str(RES_FOLDER / "timerstart.wav"))
-            timerstart.play()
+            play_sound(TIMER_START_SOUND)
             tree1.showtimer = False
 
         if tree1.breakover:
             tree1.breakover = False
             tree1.starttimer(tree1.selectedtimer, stdscr, maxx)
-            timerstart = vlc.MediaPlayer(str(RES_FOLDER / "timerstart.wav"))
-            timerstart.play()
+            play_sound(TIMER_START_SOUND)
 
     if key == ord("q"):
         treedata = open(RES_FOLDER / "treedata", "wb")
@@ -152,6 +185,9 @@ def key_events(stdscr, tree1, maxx):
             os.remove(file)
         exit()
 
+    if key == ord("u"):
+        toggle_sounds()
+
     if key in (curses.KEY_RIGHT, ord("l")):
         if tree1.showtimer:
             tree1.selectedtimer = 0
@@ -212,6 +248,26 @@ def key_events(stdscr, tree1, maxx):
         tree1.invert = True
         tree1.isnotify = True
 
+    if key == ord("}"):
+        effect_volume = min(100, effect_volume+1)
+
+        tree1.notifyendtime = int(time.time()) + 2
+
+        volume = str(effect_volume) + "%"
+        tree1.notifystring = " "*round(maxx*(effect_volume/100)-len(volume)-2) + volume
+        tree1.invert = True
+        tree1.isnotify = True
+
+    if key == ord("{"):
+        effect_volume = max(0, effect_volume-1)
+
+        tree1.notifyendtime = int(time.time()) + 2
+
+        volume = str(effect_volume) + "%"
+        tree1.notifystring = " "*round(maxx*(effect_volume/100)-len(volume)-2) + volume
+        tree1.invert = True
+        tree1.isnotify = True
+
     if key == ord("="):
 
         if tree1.media.get_time()+10000 < tree1.media.get_length():
@@ -307,10 +363,10 @@ class tree:
         self.pause = False
         self.showtimer = False
         self.timerlist = [
-            " POMODORO 20+20 ",
-            " POMODORO 20+10 ",
-            " POMODORO 40+20 ",
-            " POMODORO 50+10 ",
+            " POMODORO {}+{} ".format(TIMER_WORK_MINS[0], TIMER_BREAK_MINS[0]),
+            " POMODORO {}+{} ".format(TIMER_WORK_MINS[1], TIMER_BREAK_MINS[1]),
+            " POMODORO {}+{} ".format(TIMER_WORK_MINS[2], TIMER_BREAK_MINS[2]),
+            " POMODORO {}+{} ".format(TIMER_WORK_MINS[3], TIMER_BREAK_MINS[3]),
             " CUSTOM TIMER ",
             " END TIMER NOW ",
         ]
@@ -357,7 +413,7 @@ class tree:
             self.artfile = str(RES_FOLDER/"p4.txt")
         if self.age >= 30 and self.age < 40:
             self.artfile = str(RES_FOLDER/"p5.txt")
-        if self.age >= 40 and self.age < 60:
+        if self.age >= 40 and self.age < 70:
             self.artfile = str(RES_FOLDER/"p6.txt")
         if self.age >= 70 and self.age < 120:
             self.artfile = str(RES_FOLDER/"p7.txt")
@@ -490,8 +546,7 @@ class tree:
 
     def breakstart(self):
         if self.istimer:
-            alarm = vlc.MediaPlayer(str(RES_FOLDER / "alarm.wav"))
-            alarm.play()
+            play_sound(ALARM_SOUND)
             if self.media.is_playing():
                 self.media.pause()
             self.breakendtime = int(time.time()) + self.breaktime
@@ -514,8 +569,7 @@ class tree:
             self.media.play()
             self.isbreak = False
             self.breakover = True
-            alarm = vlc.MediaPlayer(str(RES_FOLDER / "alarm.wav"))
-            alarm.play()
+            play_sound(ALARM_SOUND)
 
     def timer(self):
         if self.istimer and int(time.time()) == int(self.workendtime):
@@ -807,8 +861,6 @@ def main():
         curses.init_pair(7, 1, 0)
 
 
-    tree_grow = vlc.MediaPlayer(RES_FOLDER/ "growth.waw")
-
     seconds = 5
     anilen = 1
     anispeed = 1
@@ -817,7 +869,7 @@ def main():
     music_volume_max = 1
 
     quote = getqt()
-    tree_grow.play()
+    play_sound(GROWTH_SOUND)
 
     tree1 = tree(stdscr, 1)
     tree1.media.play()
@@ -850,8 +902,7 @@ def main():
                     quote = getqt()
                     tree1.age += 1
                     anilen = 1
-                    tree_grow = vlc.MediaPlayer(RES_FOLDER/ "growth.waw")
-                    tree_grow.play()
+                    play_sound(GROWTH_SOUND)
 
                 if tree1.musichidetime <= int(time.time()):
                     tree1.show_music = False
